@@ -22,10 +22,6 @@
 
 #include "ar-card.h"
 
-#ifdef HAVE_CLUTTER
-#include <clutter/clutter.h>
-#endif
-
 G_BEGIN_DECLS
 
 /* A slot */
@@ -44,11 +40,6 @@ typedef struct {
   ArSlotType type;
 
   GByteArray *cards;
-#ifdef HAVE_CLUTTER
-  /* The old state of the cards so we can check for differences */
-  guint old_exposed;
-  GByteArray *old_cards;
-#endif /* HAVE_CLUTTER */
 
   /* the topmost |exposed| cards are shown on the pile */
   guint exposed;
@@ -70,13 +61,8 @@ typedef struct {
   /* The location in pixel units. Filled in by the scaling code. */
   GdkRectangle rect;
 
-#ifdef HAVE_CLUTTER
-  /* Actor for the slot */
-  ClutterActor *slot_renderer;
-#else
   /* GdkPixbuf* or GdkPixmap*, no reference owned */
   GPtrArray *card_images;
-#endif /* HAVE_CLUTTER */
 
   guint expanded_right : 1;
   guint expanded_down : 1;
@@ -103,8 +89,8 @@ char *ar_slot_get_hint_string (ArSlot *slot,
 #define AISLERIOT_IS_GAME_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), AISLERIOT_TYPE_GAME))
 #define AISLERIOT_GAME_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), AISLERIOT_TYPE_GAME, AisleriotGameClass))
 
-#define DEFAULT_VARIATION  "klondike.scm"
-#define FREECELL_VARIATION "freecell.scm"
+#define DEFAULT_VARIATION  "klondike"
+#define FREECELL_VARIATION "freecell"
 
 #define AISLERIOT_GAME_ERROR  (aisleriot_game_error_quark ())
 
@@ -186,7 +172,7 @@ void aisleriot_game_new_game_with_rand (AisleriotGame *game,
 
 void aisleriot_game_restart_game (AisleriotGame * game);
 
-const char *aisleriot_game_get_game_file (AisleriotGame * game);
+const char *aisleriot_game_get_game_module (AisleriotGame * game);
 
 char *aisleriot_game_get_name (AisleriotGame * game);
 
@@ -243,6 +229,10 @@ void aisleriot_game_get_card_offset (ArSlot *slot,
 
 void aisleriot_game_reset_old_cards (ArSlot *slot);
 
+const char *aisleriot_game_get_score (AisleriotGame *game);
+
+char **ar_get_game_modules (void);
+
 G_END_DECLS
 
 #endif /* !AISLERIOT_GAME_H */
